@@ -36,12 +36,14 @@ knit_rd = function(pkg, links = tools::findHTMLlinks(), frame = TRUE) {
     tools::Rd2HTML(pkgRdDB[[p]], f <- tempfile(),
             package = pkg, Links = links, no_links = is.null(links), stages = 'render')
     txt = readLines(f, warn = FALSE)
+    unlink(f)
     if (length(i <- grep('<h3>Examples</h3>', txt)) == 1L &&
       length(grep('</pre>', txt[i:length(txt)]))) {
       i0 = grep('<pre>', txt); i0 = i0[i0 > i][1L] - 1L
       i1 = grep('</pre>', txt); i1 = i1[i1 > i0][1L] + 1L
       tools::Rd2ex(pkgRdDB[[p]], ef <- tempfile())
       ex = readLines(ef, warn = FALSE)
+      unlink(ef)
       ex = ex[-(1L:grep('### ** Examples', ex, fixed = TRUE))]
       ex = c('```{r}', ex, '```')
       opts_chunk$set(fig.path = paste0('figure/', p, '-'), tidy = FALSE)
